/*-
 * ACPI Source Language Compiler
 *
 * Copyright (c) 2000 Mitsuru IWASAKI <iwasaki@FreeBSD.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $FreeBSD$
 */

#ifndef _ASLC_H_
#define _ASLC_H_

#include <sys/queue.h>

extern int			 parser_phase;
extern int			 parser_debuglevel;
extern int			 parser_not_initialized;
extern int			 parser_lineno;

extern void			 parser_main(const char *asl_filename);
extern void			 parser_warn(const char *msg, ...);
extern void			 parser_error(const char *msg, ...);
extern void			 parser_fatal(const char *msg, ...);

extern void			 generator_main(void);
extern void			 generator_dump_amlcode(void);
extern int			 generator_create_amlfile(const char *filename);


enum {
	LITERAL_INTEGER,
	LITERAL_STRING,
	LITERAL_MAX
};

union asl_literal {
	int		 type;

	struct {
		int		 type;
		u_int32_t	 val;
		int		 bytes;
	} num;

	struct {
		int		 type;
		char		*ptr;
	} str;
};

enum {
	SYM_METHOD,
	SYM_FIELD,
	SYM_MAX
};

struct asl_symtab {
	TAILQ_ENTRY(asl_symtab)	links;
	char			*name;
	int			 type;
	union {
		struct {
			u_int8_t	flags;
		} method;
	} data;
};

extern struct asl_symtab	*symtab_new(const char *name, int type);
extern struct asl_symtab	*symtab_find(const char *name);
extern void			 symtab_dump(void);
extern void			 symtab_destroy(void);
extern const char		*symtab_getname(struct asl_symtab *sym);
extern void			 symtab_method_setflags(struct asl_symtab *sym,
							int flags);
extern u_int8_t			 symtab_method_getnumargs(struct asl_symtab *sym);

enum {
	OBJTYPE_UNKNOWN,
	OBJTYPE_INT,
	OBJTYPE_STR,
	OBJTYPE_BUFF,
	OBJTYPE_PKG,
	OBJTYPE_FIELDUNIT,
	OBJTYPE_DEVICE,
	OBJTYPE_EVENT,
	OBJTYPE_METHOD,
	OBJTYPE_MUTEX,
	OBJTYPE_OPREGION,
	OBJTYPE_POWERRES,
	OBJTYPE_THERMALZONE,
	OBJTYPE_BUFFERFIELD,
	OBJTYPE_DDBHANDLE
};

enum {
	ACCTYPE_ANY,
	ACCTYPE_BYTE,
	ACCTYPE_WORD,
	ACCTYPE_DWORD,
	ACCTYPE_QWORD,
	ACCTYPE_BUFFER
};

enum {
	ACCATTRIB_SMBQUICK,
	ACCATTRIB_SMBSENDRECEIVE,
	ACCATTRIB_SMBBYTE,
	ACCATTRIB_SMBWORD,
	ACCATTRIB_SMBBLOCK,
	ACCATTRIB_SMBPROCESSCALL
};

enum {
	UPDATE_PRESERVE,
	UPDATE_ASONES,
	UPDATE_ASZEROS
};

enum {
	REGION_USERDEF,
	REGION_SYSTEMIO,
	REGION_SYSTEMMEM,
	REGION_PCICONFIG,
	REGION_EMBCONTROL,
	REGION_SMBUS,
	REGION_CMOS,
	REGION_PCIBARTARGET
};

enum {
	MATCH_MTR,
	MATCH_MEQ,
	MATCH_MLE,
	MATCH_MLT,
	MATCH_MGE,
	MATCH_MGT
};

enum {
	DMATYPE_COMPAT,
	DMATYPE_TYPEA,
	DMATYPE_TYPEB,
	DMATYPE_TYPEF
};

enum {
	XFERTYPE_XFER8,
	XFERTYPE_XFER16,
	XFERTYPE_XFER8_16
};

enum {
	RESOURCE_COMSUMER,
	RESOURCE_PRODUCER
};

enum {
	DECODE_SUBDECODE,
	DECODE_POSDECODE
};

enum {
	RANGETYPE_ISAONLY,
	RANGETYPE_NONISAONLY,
	RANGETYPE_ENTIRE
};

enum {
	MEMTYPE_CACHEABLE,
	MEMTYPE_WRITECOMBINING,
	MEMTYPE_PREFETCHABLE,
	MEMTYPE_NONCACHEABLE
};

enum {
	READWRITE_READWRITE,
	READWRITE_READONLY
};

enum {
	INTERRUPTTYPE_EDGE,
	INTERRUPTTYPE_LEVEL
};

enum {
	INTERRUPTLEVEL_ACTIVEHIGH,
	INTERRUPTLEVEL_ACTIVELOW
};

enum {
	SHARETYPE_SHARED,
	SHARETYPE_EXCLUSIVE
};

enum {
	IODECODE_DECODE16,
	IODECODE_DECODE10
};

enum {
	TYPE_TRANSLATION,
	TYPE_STATIC
};

enum {
	TRANSLATION_SPARSE,
	TRANSLATION_DENSE
};

enum {
	ADDRESS_MEMORY,
	ADDRESS_RESERVED,
	ADDRESS_NVS,
	ADDRESS_ACPI
};

extern void			 yyerror(const char *msg);
extern int			 yyparse(void);
extern int			 yylex(void);
extern int			 yydebug;

#endif	/* !_ASLC_H_ */
