/*-
 * ACPI Source Language Compiler
 *
 * Copyright (c) 2000 Mitsuru IWASAKI <iwasaki@FreeBSD.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $FreeBSD$
 */

#ifndef _ASLCSYMTREE_H_
#define _ASLCSYMTREE_H_

typedef u_int8_t	Byte;
typedef u_int16_t	Word;
typedef u_int32_t	DWord;
typedef u_int64_t	QWord;

enum {
	SYMTYPE_ASlCode,
	SYMTYPE_DefinitionBlock,
	SYMTYPE_TermList,
	SYMTYPE_UserTerm,
	SYMTYPE_CreateByteFieldTerm,
	SYMTYPE_MethodTerm,
	SYMTYPE_WhileTerm,
	SYMTYPE_DecTerm,
	SYMTYPE_RefOfTerm,
	SYMTYPE_StoreTerm,
	SYMTYPE_ArgTerm,
	SYMTYPE_LocalTerm,
	SYMTYPE_ByteConst,
	SYMTYPE_WordConst,
	SYMTYPE_DWordConst,
	SYMTYPE_QWordConst,
	SYMTYPE_String,
	SYMTYPE_BufferTerm,
	SYMTYPE_BufferBlock,
	SYMTYPE_NameString,
	SYMTYPE_MAX
};

#define SYMBOL_COMMON						\
	DWord		 type;					\
	DWord		 lineno;				\
	char		*name;					\
	DWord	 	 pkglength;				\
	QWord	 	 val;					\
	Byte		 encoding;				\
	Byte		 prefix

union symtree_symbol {
	struct {
		SYMBOL_COMMON;
	} common;

	struct {
		SYMBOL_COMMON;
		char	*AMLFileName;
		char	*TableSignature;
		Byte	 ComplianceRevision;
		Byte	 Checksum;
		char	*OEMID;
		char	*TableID;
		DWord	 OEMRevision;
		char	*CreatorID;
		DWord	 CreatorRevision;
	} DefinitionBlock;

	struct {
		SYMBOL_COMMON;
		char	*MethodName;
		Byte	 NumArgs;
		Byte	 SerializeRule;
		Byte	 SyncLevel;
		Byte	 Flags;
	} Method;

	struct {
		SYMBOL_COMMON;
		char	*ptr;
	} String;

	struct {
		SYMBOL_COMMON;
		QWord	BufferSize;
	} Buffer;

	struct {
		SYMBOL_COMMON;
		char	*ptr;
	} NameString;

	/* and more... */
};

struct asl_symtree {
	union symtree_symbol	 symbol;
	struct asl_symtree	*parent;
	struct asl_symtree	*brother;
	struct asl_symtree	*child;
};

extern struct asl_symtree	*symtree_new(int type, const char *symbol);
extern void			 symtree_moveptr(struct asl_symtree *symbol);
extern void			 symtree_upptr(void);
extern void			 symtree_purge(struct asl_symtree *start);
extern struct asl_symtree	*symtree_getptr(void);
extern struct asl_symtree	*symtree_getroot(void);
extern void			 symtree_dump(struct asl_symtree *start, int depth);

#endif	/* !_ASLCSYMTREE_H_ */
